// texture that is draped onto the terrain
uniform sampler2D imageTexture;

// hypsometric 1D texture
uniform sampler1D hypsoTexture;

uniform sampler2D hypsoLookUpTexture;

// 0: no texture
// 1: 1D hypsometric texture
// 2: 2D texture
uniform int textureType;

// if true, fog is added
uniform bool applyFog;

// the position to sample imageTexture
varying vec3 texCoord;

// the fog weight
varying float fog;

void main (void) {

    if (textureType == 0) {
        gl_FragColor = gl_Color;
    } else if (textureType == 1) {
        vec4 texColor = texture1D(hypsoTexture, texCoord.z);
        gl_FragColor = texColor * gl_Color;
    } else if (textureType == 2) {
        vec4 texColor = texture2D(imageTexture, texCoord.xy);
        gl_FragColor = texColor * gl_Color;
    } else { // textureType -1
        float z = texture2D(hypsoLookUpTexture, texCoord.xy).x;
        vec4 texColor = texture1D(hypsoTexture, z);
        gl_FragColor = texColor * gl_Color;
    }

    if (applyFog) {
        gl_FragColor = mix(gl_Fog.color, gl_FragColor, fog);
    }

}